.. _sec_examples:

========
Examples
========

.. toctree::
  :maxdepth: 2


.. fancy_include:: overview_plot.py

.. fancy_include:: emodulus_dcor.py

.. fancy_include:: lme4_lmer.py

.. fancy_include:: lme4_glmer_diff.py

.. fancy_include:: ml_tensorflow.py

.. fancy_include:: ml_builtin.py

.. fancy_include:: isoelastics.py

.. fancy_include:: plugin_usage.py
